%define major      19
%define libname    %mklibname tsk %{major}
%define develname  %mklibname tsk -d

Summary:        The Sleuth Kit
Name:           sleuthkit
Version:        4.12.0
Release:        %mkrel 1
License:        CPL
Group:          Security
URL:            https://www.sleuthkit.org/sleuthkit/
Source0:        https://github.com/sleuthkit/sleuthkit/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig(afflib)
BuildRequires:  pkgconfig(libewf)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(sqlite3)

Requires:       mac-robber
Requires:       file
Requires:       afflib
Requires:       libewf
Provides:       task = %{version}
Obsoletes:      task = %{version}
Conflicts:      dstat

%description
The Sleuth Kit (previously known as TASK) is a collection of UNIX-based command
line file system forensic tools that allow an investigator to examine NTFS,
FAT, FFS, EXT2FS, EXT3FS and ExFAT file systems of a suspect computer in a
non-intrusive fashion. The  tools have a layer-based design and can extract
data from internal file system structures. Because the tools do not rely on the
operating system to process the file systems, deleted and hidden content is
shown.

When performing a complete analysis of a system, command line tools can become
tedious. The Autopsy Forensic Browser is a graphical interface to the tools in
The Sleuth Kit, which allows one to more easily conduct an investigation.
Autopsy provides case management, image integrity, keyword searching, and other
automated operations.

%package -n     %{libname}
Summary:        Library for %{name}
Group:          System/Libraries

%description -n %{libname}
The %{libname} package contains library for %{name}.

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{develname} package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1 -n %{name}-%{name}-%{version}

%build
autoreconf -vif
export LIBS='-lpthread -ldl -lm -lstdc++'

%configure --disable-static --disable-java

# remove rpath from libtool (fedora)
sed -i.rpath 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i.rpath 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

%files
%doc ChangeLog.txt NEWS.txt README.md licenses/*
# License is CPL 1.0 exept for some files.
%{_bindir}/blkcalc
%{_bindir}/blkcat
%{_bindir}/blkls
%{_bindir}/blkstat
%{_bindir}/fcat
%{_bindir}/ffind
%{_bindir}/fiwalk
%{_bindir}/fls
%{_bindir}/fsstat
%{_bindir}/hfind
%{_bindir}/icat
%{_bindir}/ifind
%{_bindir}/ils
%{_bindir}/img_cat
%{_bindir}/img_stat
%{_bindir}/istat
%{_bindir}/jcat
%{_bindir}/jpeg_extract
%{_bindir}/jls
# This file is described as GPL in the doc
# But the license remains CPL in the source.
%{_bindir}/mactime
##
%{_bindir}/mmcat
%{_bindir}/mmls
%{_bindir}/mmstat
%{_bindir}/pstat
%{_bindir}/sigfind
%{_bindir}/sorter
%{_bindir}/tsk_comparedir
%{_bindir}/tsk_gettimes
%{_bindir}/tsk_imageinfo
%{_bindir}/tsk_loaddb
%{_bindir}/tsk_recover
%{_bindir}/usnjls
## This file is GPLv2+
%{_bindir}/srch_strings
#
%{_mandir}/man1/blkcalc.1*
%{_mandir}/man1/blkcat.1*
%{_mandir}/man1/blkls.1*
%{_mandir}/man1/blkstat.1*
%{_mandir}/man1/fcat.1*
%{_mandir}/man1/ffind.1*
%{_mandir}/man1/fls.1*
%{_mandir}/man1/fsstat.1*
%{_mandir}/man1/hfind.1*
%{_mandir}/man1/icat.1*
%{_mandir}/man1/ifind.1*
%{_mandir}/man1/ils.1*
%{_mandir}/man1/img_cat.1*
%{_mandir}/man1/img_stat.1*
%{_mandir}/man1/istat.1*
%{_mandir}/man1/jcat.1*
%{_mandir}/man1/jls.1*
%{_mandir}/man1/mactime.1*
%{_mandir}/man1/mmcat.1*
%{_mandir}/man1/mmls.1*
%{_mandir}/man1/mmstat.1*
%{_mandir}/man1/sigfind.1*
%{_mandir}/man1/sorter.1*
%{_mandir}/man1/tsk_comparedir.1*
%{_mandir}/man1/tsk_gettimes.1*
%{_mandir}/man1/tsk_loaddb.1*
%{_mandir}/man1/tsk_recover.1*
%{_mandir}/man1/usnjls.1*
%dir %{_datadir}/tsk
%{_datadir}/tsk/sorter/

%files -n %{libname}
%{_libdir}/libtsk.so.%{major}{,.*}

%files -n %{develname}
# CPL and IBM
%{_includedir}/tsk/
%{_libdir}/libtsk.so
%{_libdir}/pkgconfig/tsk.pc


%changelog
* Wed Dec 28 2022 daviddavid <daviddavid> 4.12.0-1.mga9
+ Revision: 1927487
- new version: 4.12.0

* Mon Nov 14 2022 daviddavid <daviddavid> 4.11.1-1.mga9
+ Revision: 1907162
- new version: 4.11.1

* Sun Mar 27 2022 umeabot <umeabot> 4.10.2-2.mga9
+ Revision: 1829479
- Mageia 9 Mass Rebuild

* Wed Mar 24 2021 daviddavid <daviddavid> 4.10.2-1.mga9
+ Revision: 1709091
- new version: 4.10.2

* Sat Mar 20 2021 tv <tv> 4.10.1-2.mga9
+ Revision: 1705566
- rebuild for python-3.9.2

* Sat Dec 26 2020 daviddavid <daviddavid> 4.10.1-1.mga8
+ Revision: 1663867
- new version: 4.10.1

* Thu Oct 22 2020 daviddavid <daviddavid> 4.10.0-1.mga8
+ Revision: 1638128
- new version: 4.10.0

* Sat May 09 2020 daviddavid <daviddavid> 4.9.0-1.mga8
+ Revision: 1581895
- new version: 4.9.0
- remove merged upstream patch

* Sat Mar 14 2020 daviddavid <daviddavid> 4.8.0-3.mga8
+ Revision: 1556367
- add upstream patch to fix CVE-2020-10232 (mga#26336)

* Thu Feb 20 2020 umeabot <umeabot> 4.8.0-2.mga8
+ Revision: 1547264
- Mageia 8 Mass Rebuild

* Fri Feb 07 2020 daviddavid <daviddavid> 4.8.0-1.mga8
+ Revision: 1487747
- new version: 4.8.0
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Nov 21 2019 daviddavid <daviddavid> 4.7.0-1.mga8
+ Revision: 1461960
- new version: 4.7.0
- now libmajor is 19

* Mon Aug 19 2019 daviddavid <daviddavid> 4.6.7-1.mga8
+ Revision: 1430145
- new version: 4.6.7

* Fri May 24 2019 daviddavid <daviddavid> 4.6.6-1.mga7
+ Revision: 1399028
- new version: 4.6.6

* Sat Mar 02 2019 daviddavid <daviddavid> 4.6.5-1.mga7
+ Revision: 1370986
- new version: 4.6.5

* Wed Jan 09 2019 tv <tv> 4.6.4-2.mga7
+ Revision: 1352975
- rebuild with python 3.7

* Mon Dec 10 2018 daviddavid <daviddavid> 4.6.4-1.mga7
+ Revision: 1340046
- new version: 4.6.4

* Sun Sep 23 2018 umeabot <umeabot> 4.6.2-3.mga7
+ Revision: 1301064
- Mageia 7 Mass Rebuild

* Mon Aug 13 2018 daviddavid <daviddavid> 4.6.2-2.mga7
+ Revision: 1251297
- use system sqlite3
- new version: 4.6.2

* Tue Jul 17 2018 daviddavid <daviddavid> 4.6.1-1.mga7
+ Revision: 1244087
- new version: 4.6.1

* Sun Mar 25 2018 daviddavid <daviddavid> 4.6.0-1.mga7
+ Revision: 1212329
- new version: 4.6.0

* Mon Jan 08 2018 daviddavid <daviddavid> 4.5.0-1.mga7
+ Revision: 1191455
- new version: 4.5.0

* Sun Aug 20 2017 daviddavid <daviddavid> 4.4.2-1.mga7
+ Revision: 1142414
- new version: 4.4.2

* Sat Jan 21 2017 daviddavid <daviddavid> 4.4.0-1.mga6
+ Revision: 1082830
- new version: 4.4.0

* Fri Aug 12 2016 daviddavid <daviddavid> 4.3.0-1.mga6
+ Revision: 1046079
- new version: 4.3.0
- update Source URL

* Sun Jan 24 2016 daviddavid <daviddavid> 4.2.0-1.mga6
+ Revision: 926976
- new version: 4.2.0
- now libmajor is 13
- switch to %%configure2_5x to fix build
- switch BRs to pkgconfig()

* Wed Oct 15 2014 umeabot <umeabot> 4.1.3-4.mga5
+ Revision: 750866
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 4.1.3-3.mga5
+ Revision: 730144
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 4.1.3-2.mga5
+ Revision: 689191
- Mageia 5 Mass Rebuild

* Sat Jun 21 2014 malo <malo> 4.1.3-1.mga5
+ Revision: 638255
- update to 4.1.3

* Sat Oct 19 2013 umeabot <umeabot> 4.1.0-3.mga4
+ Revision: 532218
- Mageia 4 Mass Rebuild

* Sun Aug 18 2013 malo <malo> 4.1.0-2.mga4
+ Revision: 467556
- fixing Obsoletes

* Sun Aug 18 2013 malo <malo> 4.1.0-1.mga4
+ Revision: 467543
- remove java lib from rpm
- update to 4.1.0
- remove api on libtsk

* Sun Jun 16 2013 malo <malo> 4.0.2-2.mga4
+ Revision: 443680
- fix file list
- update to 4.0.2 (patch by William Murphy)

* Mon Jan 14 2013 umeabot <umeabot> 4.0.1-2.mga3
+ Revision: 382159
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 malo <malo> 4.0.1-1.mga3
+ Revision: 339387
- remove java libs from file list
- update to 4.0.1
- add patch to fix build with automake-1.13
- update build in spec, following fedora

* Sun Sep 30 2012 malo <malo> 3.2.3-3.mga3
+ Revision: 300673
- Update RPM group

* Sun Mar 04 2012 sander85 <sander85> 3.2.3-2.mga2
+ Revision: 218108
- rebuild for new libewf

* Sun Jan 29 2012 malo <malo> 3.2.3-1.mga2
+ Revision: 203020
- new version 3.2.3
- mac-robber is now in a separate package
- spec clean-up after import from Mandriva
- imported package sleuthkit


* Tue Dec 07 2010 Oden Eriksson <oeriksson@mandriva.com> 3.0.1-3mdv2011.0
+ Revision: 614899
- the mass rebuild of 2010.1 packages

* Mon Apr 12 2010 Funda Wang <fwang@mandriva.org> 3.0.1-2mdv2010.1
+ Revision: 533653
- fix linkage

* Mon Jul 20 2009 Frederik Himpe <fhimpe@mandriva.org> 3.0.1-1mdv2010.0
+ Revision: 398108
- Update to new version 3.0.1
- Run autoreconf to fix --disable-static configure option
- Remove rpath
- Remove unused .la files
- Remove unbundle patch which is not needed anymore
- Create libtsk3 subpackages
- Fix file list (synced with Fedora)
- BuildRequires: libncurses-devel

* Sat Aug 02 2008 Thierry Vignaud <tv@mandriva.org> 2.09-4mdv2009.0
+ Revision: 260795
- rebuild

* Tue Jul 29 2008 Thierry Vignaud <tv@mandriva.org> 2.09-3mdv2009.0
+ Revision: 252599
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 2.09-1mdv2008.1
+ Revision: 136503
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Sep 07 2007 Oden Eriksson <oeriksson@mandriva.com> 2.09-1mdv2008.0
+ Revision: 81984
- 2.09
- unbundle file, afflib and libewf

* Fri Aug 31 2007 Oden Eriksson <oeriksson@mandriva.com> 2.05-2mdv2008.0
+ Revision: 76894
- rebuild


* Sat Jul 29 2006 Oden Eriksson <oeriksson@mandriva.com> 2.05-1mdv2007.0
- 2.05
- fix deps

* Wed Oct 19 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.03-1mdk
- New release 2.03
- %%mkrel

* Sun Dec 26 2004 Stefan van der Eijk <stefan@mandrake.org> 1.73-1mdk
- 1.73
- rediffed p0

* Thu Nov 25 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 1.72-2mdk
- fix #12488

* Sun Oct 31 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 1.72-1mdk
- 1.72
- fix P0

* Wed Sep 01 2004 Stefan van der Eijk <stefan@mandrake.org> 1.71-1mdk
- 1.71

* Thu May 06 2004 Michael Scherer <misc@mandrake.org> 1.69-1mdk
- New release 1.69
- rpmbuildupdate aware
- update patch
- [DIRM]

